@@ -31,14 +31,14 @@ from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.recipe import Recipe
 from tiddlyweb.model.user import User
 from tiddlyweb.model.policy import Policy
-from tiddlyweb.store import NoRecipeError, NoTiddlerError, NoUserError, \
-	StoreMethodNotImplemented
+from tiddlyweb.store import (NoRecipeError, NoBagError, NoTiddlerError,
+	NoUserError, StoreMethodNotImplemented)
 from tiddlyweb.stores import StorageInterface
 from tiddlyweb.serializer import Serializer
 from tiddlyweb.util import read_utf8_file, write_utf8_file
 
 
-__version__ = "0.4.4"
+__version__ = "0.5.4"
 
 # XXX: should be class attributes?
 RECIPE_EXT = ".recipe"
@@ -105,6 +105,9 @@ class Store(StorageInterface):
 
 		bag_path = self._bag_path(bag)
 
+		if not (self._index.get(bag.name, None) or os.path.isdir(bag_path)):
+			raise NoBagError
+
 		if not getattr(bag, "skinny", False):
 			locals = [filename[:-4] for filename in os.listdir(bag_path)
 				if filename.endswith(TIDDLER_EXT)]
@@ -144,7 +147,10 @@ class Store(StorageInterface):
 		try:
 			tiddler = self._get_local_tiddler(tiddler)
 		except IOError:
-			tiddler = self._get_remote_tiddler(tiddler)
+			try:
+				tiddler = self._get_remote_tiddler(tiddler)
+			except KeyError, exc:
+				raise NoTiddlerError(exc)
 		tiddler.revision = 1
 		return tiddler
 
